@@ -3,7 +3,7 @@
 /*
     This file is part of Magnum.
 
-    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
+    Copyright © 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019
               Vladimír Vondruš <mosra@centrum.cz>
 
     Permission is hereby granted, free of charge, to any person obtaining a
@@ -29,8 +29,8 @@
  * @brief Class @ref Magnum::DebugTools::CompareImage
  */
 
-#include <memory>
 #include <vector>
+#include <Corrade/Containers/Pointer.h>
 #include <Corrade/PluginManager/PluginManager.h>
 #include <Corrade/TestSuite/Comparator.h>
 
@@ -80,7 +80,7 @@ class MAGNUM_DEBUGTOOLS_EXPORT ImageComparatorBase {
 
         enum class State: UnsignedByte;
 
-        std::unique_ptr<FileState> _fileState;
+        Containers::Pointer<FileState> _fileState;
         Float _maxThreshold, _meanThreshold;
 
         State _state{};
@@ -142,7 +142,12 @@ namespace Magnum { namespace DebugTools {
 /**
 @brief Image comparator
 
-To be used with @ref Corrade::TestSuite. Basic use is really simple:
+To be used with @ref Corrade::TestSuite.
+
+@note This class is available only if Magnum is compiled with `WITH_TRADE`
+    enabled (done by default). See @ref building-features for more information.
+
+Basic use is really simple:
 
 @snippet debugtools-compareimage.cpp 0
 
